#!/bin/sh

# ========================================================================
# Система "iBank" Автоклиент
# Установка переменных окружения JAVA и AUTOCLIENT_HOME
#     JAVA - команда для запуска java-машины
#     AUTOCLIENT_HOME - каталог, в который установлен модуль "Автоклиент"
# ========================================================================

export JAVA=$JAVA_HOME/bin/java

export AUTOCLIENT_HOME=..

if [ $(uname -m) = "x86_64" ]; then
    export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$AUTOCLIENT_HOME/lib/native/linux-x86_64
else
    export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$AUTOCLIENT_HOME/lib/native/linux-i586
fi


# ========================================================================
# Проверка Java
# ========================================================================

REQUIRED_VERSION=1.8

if [ -z $JAVA ]; then
    echo "ERROR:"
    echo "Не установлено значение переменной JAVA в скрипте setEnviroment.sh"
    exit
fi

if [ ! -f $JAVA ]; then
    echo "ERROR:"
    echo "Не найден файл $JAVA"
    echo "Проверьте корректно ли значение переменной JAVA в скрипте setEnviroment.sh"
    exit
fi

VERSION=`$JAVA -version 2>&1 | grep "java version" | awk 'BEGIN {FS="\""} {print $2}'`

if [ -z $VERSION ]; then
    echo "ERROR:"
    echo "Не удалось определить версию Java Runtime Environment (JRE)"
    echo "Проверьте корректно ли значение переменной JAVA в скрипте setEnviroment.sh"
    exit
fi

getVersionNum(){
    echo $1 | awk 'BEGIN {FS="\\."} {print $1*100+$2}'
}

VERSION_NUM=$(getVersionNum $VERSION)
REQUIRED_VERSION_NUM=$(getVersionNum $REQUIRED_VERSION)

if [ $VERSION_NUM -lt $REQUIRED_VERSION_NUM ]; then
    echo "ERROR:"
    echo "На вашем компьютере установлена Java Runtime Environment (JRE) версии $VERSION"
    echo "Для работы программы необходима JRE версии $REQUIRED_VERSION или выше"
    exit
fi

echo "Версия Java Runtime Environment (JRE): $VERSION"
